@@ -61,8 +61,14 @@ class PyKriging {
 
   std::string summary() const;
 
+  void save(const std::string filename) const;
+
+  static PyKriging load(const std::string filename);
+
   std::tuple<double, py::array_t<double>> leaveOneOutFun(const py::array_t<double>& theta, const bool want_grad);
 
+  std::tuple<py::array_t<double>, py::array_t<double>> leaveOneOutVec(const py::array_t<double>& theta);
+
   std::tuple<double, py::array_t<double>, py::array_t<double>> logLikelihoodFun(const py::array_t<double>& theta,
                                                                                 const bool want_grad,
                                                                                 const bool want_hess);
