@@ -64,6 +64,10 @@ class PyNoiseKriging {
 
   std::string summary() const;
 
+  void save(const std::string filename) const;
+
+  static PyNoiseKriging load(const std::string filename);
+
   std::tuple<double, py::array_t<double>> logLikelihoodFun(const py::array_t<double>& theta_alpha,
                                                            const bool want_grad);
 
