@@ -129,7 +129,10 @@ PYBIND11_MODULE(_pylibkriging, m) {
       .def("simulate", &PyKriging::simulate)
       .def("update", &PyKriging::update)
       .def("summary", &PyKriging::summary)
+      .def("save", &PyKriging::save)
+      .def_static("load", &PyKriging::load)
       .def("leaveOneOutFun", &PyKriging::leaveOneOutFun)
+      .def("leaveOneOutVec", &PyKriging::leaveOneOutVec)
       .def("logLikelihoodFun", &PyKriging::logLikelihoodFun)
       .def("logMargPostFun", &PyKriging::logMargPostFun)
       .def("logLikelihood", &PyKriging::logLikelihood)
@@ -187,6 +190,8 @@ PYBIND11_MODULE(_pylibkriging, m) {
       .def("simulate", &PyNuggetKriging::simulate)
       .def("update", &PyNuggetKriging::update)
       .def("summary", &PyNuggetKriging::summary)
+      .def("save", &PyNuggetKriging::save)
+      .def_static("load", &PyNuggetKriging::load)
       .def("logLikelihoodFun", &PyNuggetKriging::logLikelihoodFun)
       .def("logMargPostFun", &PyNuggetKriging::logMargPostFun)
       .def("logLikelihood", &PyNuggetKriging::logLikelihood)
@@ -248,6 +253,8 @@ PYBIND11_MODULE(_pylibkriging, m) {
       .def("simulate", &PyNoiseKriging::simulate)
       .def("update", &PyNoiseKriging::update)
       .def("summary", &PyNoiseKriging::summary)
+      .def("save", &PyNoiseKriging::save)
+      .def_static("load", &PyNoiseKriging::load)
       .def("logLikelihoodFun", &PyNoiseKriging::logLikelihoodFun)
       .def("logLikelihood", &PyNoiseKriging::logLikelihood)
 
