@@ -7,13 +7,11 @@ fi
 
 case "$(uname -s)" in
  Darwin)
-   brew install gfortran
    brew install hdf5
    ;;
 
  Linux)
-   sudo apt install gfortran
-   sudo apt install libhdf5-dev
+   sudo apt install -y libhdf5-dev
    ;;
 
  *)
