@@ -30,29 +30,9 @@ export EXTRA_SYSTEM_LIBRARY_PATH=${HOME}/Miniconda3/Library/lib
 # export EXTRA_SYSTEM_LIBRARY_PATH="C:/Program Files/MATLAB/R2022a/extern/lib/win64/microsoft"
 # EXTRA_CMAKE_OPTIONS="${EXTRA_CMAKE_OPTIONS} -DBLAS_NAMES=libmwblas -DLAPACK_NAMES=libmwlapack"
 
-if [[ -z ${CMAKE_Fortran_COMPILER} ]]; then
-  if ( command -v R >/dev/null 2>&1 ); then
-    CMAKE_Fortran_COMPILER="$(R CMD config FC | awk '{ print $1 }')"
-  else
-    echo "R not available; fall back to naive gfortran"
-    CMAKE_Fortran_COMPILER=gfortran
-  fi
-fi
-
-if [[ -z ${Fortran_LINK_FLAGS} ]]; then
-  if ( command -v R >/dev/null 2>&1 ); then
-    Fortran_LINK_FLAGS="$(R CMD config FLIBS)"
-  else
-    Fortran_LINK_FLAGS="-lgfortran -lquadmath"
-  fi
-fi
-
-
 mkdir -p ${BUILD_DIR:-build}
 cd ${BUILD_DIR:-build}
 cmake \
-  -DCMAKE_Fortran_COMPILER="${CMAKE_Fortran_COMPILER}" \
-  -DFortran_LINK_FLAGS="${Fortran_LINK_FLAGS}" \
   -DCMAKE_GENERATOR_PLATFORM=x64 \
   -DEXTRA_SYSTEM_LIBRARY_PATH="${EXTRA_SYSTEM_LIBRARY_PATH}" \
   -DENABLE_OCTAVE_BINDING=${ENABLE_OCTAVE_BINDING} \
