@@ -42,7 +42,7 @@ export Fortran_LINK_FLAGS="$(${R_HOME}/bin/R CMD config FLIBS)"
 echo "----------------------------------------------------------------"
 echo "Look for HDF5 installation"
 # Get HDF5 installation if available from R package Rhdf5lib
-RHDF5_PATH=$(${R_HOME}/bin/Rscript -e "system.file(package='Rhdf5lib')" | sed -e 's/^\[[0-9]\] "//' | sed -e 's/"$//')
+RHDF5_PATH=$(${R_HOME}/bin/R -s -e "system.file(package='Rhdf5lib')" | sed -e 's/^\[[0-9]\] "//' | sed -e 's/"$//')
 if [ -n "${RHDF5_PATH}" ]; then
   rm -fr ../../inst/hdf5
   mkdir -p ../../inst/hdf5
@@ -62,10 +62,14 @@ MODE=Release \
 EXTRA_CMAKE_OPTIONS="${EXTRA_CMAKE_OPTIONS:-} -DCMAKE_INSTALL_LIBDIR=lib -DBUILD_SHARED_LIBS=${MAKE_SHARED_LIBS} -DEXTRA_SYSTEM_LIBRARY_PATH=${EXTRA_SYSTEM_LIBRARY_PATH}" \
 $CI/linux-macos/build.sh # should support '.travis-ci' or 'travis-ci'"
 
-mv ../../inst/hdf5 ../../hdf5
+if [ -n "${HDF5_ROOT}" ]; then
+  mv ${HDF5_ROOT} ../../hdf5
+fi
 rm -rf ../../inst
 mkdir -p ../../inst
-mv ../../hdf5 ../../inst/hdf5
+if [ -n "${HDF5_ROOT}" ]; then
+  mv ../../hdf5 ${HDF5_ROOT}
+fi
 mv build/installed/lib ../../inst/.
 mv build/installed/share ../../inst/.
 mv build/installed/include ../../inst/.
@@ -73,6 +77,6 @@ mv build/installed/include ../../inst/.
 cd ../..
 
 # update doc
-#Rscript -e "roxygen2::roxygenise(package.dir = '.')" # No: it will loop on install, because roxygen2 requires loading package...
+#R -e "roxygen2::roxygenise(package.dir = '.')" # No: it will loop on install, because roxygen2 requires loading package...
 # update Rccp links
-${R_HOME}/bin/Rscript -e "Rcpp::compileAttributes(pkgdir = '.', verbose = TRUE)"
+${R_HOME}/bin/R -e "Rcpp::compileAttributes(pkgdir = '.', verbose = TRUE)"
